summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/kkbdaccessextensions.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/kkbdaccessextensions.h')
-rw-r--r--lib/kofficecore/kkbdaccessextensions.h48
1 files changed, 24 insertions, 24 deletions
diff --git a/lib/kofficecore/kkbdaccessextensions.h b/lib/kofficecore/kkbdaccessextensions.h
index acca057c..bc68cb28 100644
--- a/lib/kofficecore/kkbdaccessextensions.h
+++ b/lib/kofficecore/kkbdaccessextensions.h
@@ -24,28 +24,28 @@
#ifndef __KKBDACCESSEXTENSIONS_H__
#define __KKBDACCESSEXTENSIONS_H__
-// Qt includes.
-#include <qobject.h>
+// TQt includes.
+#include <tqobject.h>
// KOffice includes.
#include <koffice_export.h>
class KKbdAccessExtensionsPrivate;
-class QWidgetList;
+class TQWidgetList;
class KMainWindow;
/** KKbdAccessExtensions is an object that improves accessibility for motor impaired users
* who may not be able to easily use a mouse. It adds two new capabilities using the keyboard:
*
-* - Resizing and positioning of panel widgets derived from QSplitter and QDockWindow.
+* - Resizing and positioning of panel widgets derived from TQSplitter and TQDockWindow.
* - Setting focus to any widget that accepts focus.
*
* @section sizing_mode Sizing Mode
*
* Users may press F8 or Shift-F8 (defaults) to enter sizing mode. A sizing icon appears on the first
-* QSplitter or QDockWindow handle found in the application (F8) or the last such handle (Shift+F8).
+* TQSplitter or TQDockWindow handle found in the application (F8) or the last such handle (Shift+F8).
* (A "handle" is the divider bar that appears to the left, right, above, or below each panel
-* of a QSplitter or QDockArea.)
+* of a TQSplitter or TQDockArea.)
*
* Once in sizing mode, the following functions are available via the keyboard:
*
@@ -62,19 +62,19 @@ class KMainWindow;
* When on a horizontal sizing handle, moves the handle down.
* - PgUp Like LeftArrow or UpArrow, but moves the handle 5X farther to the left or up.
* - PgDn Like RightArrow or DownArrow, but moves the handle 5X farther to the right or down.
-* - Enter (On numeric keypad). When on the handle of a QDockWindow, undocks or docks
-* the widget. Ignored when on the handle of a QSplitter.
+* - Enter (On numeric keypad). When on the handle of a TQDockWindow, undocks or docks
+* the widget. Ignored when on the handle of a TQSplitter.
*
* The default step size for each arrow key press is 10 pixels.
*
-* When a QDockWindow is undocked, the sizing icon appears in the center of the window.
+* When a TQDockWindow is undocked, the sizing icon appears in the center of the window.
* The arrow keys and PgUp/PgDn move the undocked window on the screen. Shifted arrow keys
* and PgUp/PgDn decrease/increase the size of the undocked window.
*
* When the sizing icon is on a sizing handle, the mouse may also be used to move the handle
* without having to click and drag. When moving the mouse while sizing icon is on an undocked
-* QDockWindow, the window moves with the mouse. Holding Shift down while moving the mouse
-* sizes the QDockWindow.
+* TQDockWindow, the window moves with the mouse. Holding Shift down while moving the mouse
+* sizes the TQDockWindow.
*
* @note Users can also move and size undocked windows using the Window Operations Menu (Alt+F3).
*
@@ -83,7 +83,7 @@ class KMainWindow;
* When entering sizing mode, the position of the mouse cursor is saved and restored when
* exiting sizing mode.
*
-* For a QSplitter or QDockWindow to be found, it must be in the kapp::allWidgets() list.
+* For a TQSplitter or TQDockWindow to be found, it must be in the kapp::allWidgets() list.
*
* @section focus_setting Focus Setting
*
@@ -107,17 +107,17 @@ class KMainWindow;
* F8/Shift+F8 are the default shortcuts because these are the keys used for similar
* functionality in GNOME and Java SWT.
*/
-class KOFFICECORE_EXPORT KKbdAccessExtensions : public QObject
+class KOFFICECORE_EXPORT KKbdAccessExtensions : public TQObject
{
- // TODO: A .moc isn't really needed right now, but see TODO in eventFilter method.
- // Q_PROPERTY(int stepSize READ stepSize WRITE setStepSize)
+ // TODO: A .tqmoc isn't really needed right now, but see TODO in eventFilter method.
+ // TQ_PROPERTY(int stepSize READ stepSize WRITE setStepSize)
public:
/** Constructor.
* @param parent KMainWindow of the application. Required.
* @param name (optional) Name of this object.
*/
- KKbdAccessExtensions(KMainWindow* parent, const char* name = 0);
+ KKbdAccessExtensions(KMainWindow* tqparent, const char* name = 0);
/** Destructor. */
virtual ~KKbdAccessExtensions();
@@ -129,10 +129,10 @@ class KOFFICECORE_EXPORT KKbdAccessExtensions : public QObject
protected:
/** Event filter installed on kapp object. */
- bool eventFilter( QObject *o, QEvent *e );
+ bool eventFilter( TQObject *o, TQEvent *e );
/** Retrieves a list of all Splitter and DockArea widgets in the application. */
- QWidgetList* getAllPanels();
+ TQWidgetList* getAllPanels();
/** Advances to the next Panel handle. If not currently in resizing mode,
turns it on. */
void nextHandle();
@@ -153,23 +153,23 @@ class KOFFICECORE_EXPORT KKbdAccessExtensions : public QObject
/** Displays the access keys. */
void displayAccessKeys();
/** Handles an access keypress. */
- bool handleAccessKey( const QKeyEvent* ev );
+ bool handleAccessKey( const TQKeyEvent* ev );
private:
KKbdAccessExtensionsPrivate* d;
};
-/** Provides a way to sort QLabelss using a QValueList based on their screen position. */
+/** Provides a way to sort TQLabelss using a TQValueList based on their screen position. */
class KSortedLabel
{
public:
- KSortedLabel(QLabel* l);
+ KSortedLabel(TQLabel* l);
KSortedLabel(); // default constructor
bool operator<( KSortedLabel l);
- QLabel* label() { return m_l; }
+ TQLabel* label() { return m_l; }
private:
- QLabel* m_l;
+ TQLabel* m_l;
};
#endif // __KKBDACCESSEXTENSIONS_H__
@@ -107,17 +107,17 @@ class KMainWindow;
public:
/** Constructor.
- * @param parent KMainWindow of the application. Required.
+ * @param tqparent KMainWindow of the application. Required.
* @param name (optional) Name of this object.
*/